@@ -294,13 +294,13 @@ def schnitzler(files, indices, doc_person, work_list):  # pragma: no cover
                 back_node.append(list_place_node)
         work_matches = list_work.any_xpath(f".//tei:body//*[@when='{day}']/parent::*")
         if len(work_matches) > 0:
-            list_bibl_node = ET.Element("{http://www.tei-c.org/ns/1.0}listBible")
+            list_bibl_node = ET.Element("{http://www.tei-c.org/ns/1.0}listBibl")
             for work in work_matches:
                 title_node = work.xpath('./*[@key]')[0]
                 title_text = title_node.text
                 title_id = title_node.xpath('@key')[0]
                 bibl_node = ET.Element("{http://www.tei-c.org/ns/1.0}bibl")
-                title_node = ET.Element("{http://www.tei-c.org/ns/1.0}bibl")
+                title_node = ET.Element("{http://www.tei-c.org/ns/1.0}title")
                 title_node.text = title_text
                 bibl_node.set('{http://www.w3.org/XML/1998/namespace}id', title_id)
                 bibl_node.append(title_node)
